Neopixel example
================

Yes, it's near christmas. This is therefore the ideal time to do this, and
write this. This example shows how to use the Adafruit Neopixel library in
Pyxie.


Manually:
    1. Clone https://github.com/adafruit/Adafruit_NeoPixel
    2. Copy (or symlink) the directory into /usr/share/arduino/libraries
    3. Done.

TO BE DONE:

Less Manually:
    1. Clone https://github.com/sparkslabs/neopixel-packaging
    2. Run make
    3. Install adafruit-neopixel

Even less Manually - if you're using Ubuntu 16.04LTS
    1. Make sure you're using my ppa
    2. sudo apt-get install adafruit-neopixel